@@ -302,6 +302,8 @@ class StandaloneHTMLBuilder(Builder):
             docstitle = self.config.html_title,
             shorttitle = self.config.html_short_title,
             show_copyright = self.config.html_show_copyright,
+            enable_comments = self.config.enable_comments,
+            disqus_site = self.config.disqus_site,
             show_sphinx = self.config.html_show_sphinx,
             has_source = self.config.html_copy_source,
             show_source = self.config.html_show_sourcelink,
